==> gnome-system-monitor-3.9.5.tar.xz: gnome-system-monitor-3.9.5/src/procdialogs.h <==
/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* Procman - dialogs
 * Copyright (C) 2001 Kevin Vandersloot
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 *
 */
#ifndef _PROCDIALOGS_H_
#define _PROCDIALOGS_H_


#include <glib.h>
#include "procman-app.h"

/* These are the actual range of settable values. Values outside this range
   are scaled back to these limits. So show these limits in the slider
*/
#ifdef __linux__
#define RENICE_VAL_MIN -20
#define RENICE_VAL_MAX 19
#else /* ! linux */
#define RENICE_VAL_MIN -20
#define RENICE_VAL_MAX 20
#endif


typedef enum
{
    PROCMAN_ACTION_RENICE,
    PROCMAN_ACTION_KILL
} ProcmanActionType;


void                    procdialog_create_kill_dialog (ProcmanApp *app, int signal);
void                    procdialog_create_renice_dialog (ProcmanApp *app);
gboolean                procdialog_create_root_password_dialog (ProcmanActionType type,
                                                                ProcmanApp *app,
                                                                gint pid, gint extra_value);
void                    procdialog_create_memmaps_dialog (ProcmanApp *app);
void                    procdialog_create_preferences_dialog (ProcmanApp *app);

#endif

==> gnome-system-monitor-3.11.4.tar.xz: gnome-system-monitor-3.11.4/src/procdialogs.h <==
/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* Procman - dialogs
 * Copyright (C) 2001 Kevin Vandersloot
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 *
 */
#ifndef _GSM_PROCDIALOGS_H_
#define _GSM_PROCDIALOGS_H_


#include <glib.h>
#include "application.h"

/* These are the actual range of settable values. Values outside this range
   are scaled back to these limits. So show these limits in the slider
*/
#ifdef __linux__
#define RENICE_VAL_MIN -20
#define RENICE_VAL_MAX 19
#else /* ! linux */
#define RENICE_VAL_MIN -20
#define RENICE_VAL_MAX 20
#endif


typedef enum
{
    PROCMAN_ACTION_RENICE,
    PROCMAN_ACTION_KILL
} ProcmanActionType;


void                    procdialog_create_kill_dialog (GsmApplication *app, int signal);
void                    procdialog_create_renice_dialog (GsmApplication *app);
gboolean                procdialog_create_root_password_dialog (ProcmanActionType type,
                                                                GsmApplication *app,
                                                                gint pid, gint extra_value);
void                    procdialog_create_memmaps_dialog (GsmApplication *app);

#endif /* _GSM_PROCDIALOGS_H_ */
